@@ -21,6 +21,8 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301
  *  USA
  *
+ * SPDX-License-Identifier: LGPL-2.1
+ *
  *
  * Touch screen library interface definitions.
  */
@@ -86,19 +88,25 @@ struct ts_sample_mt {
 	/* BTN_TOUCH state */
 	short		pen_down;
 
-	/* valid is set to 1 if this sample
-	 * contains new data; set to 0 otherwise
+	/* valid is set != 0 if this sample
+	 * contains new data; see below for the
+	 * bits that get set.
+	 * valid is set to 0 otherwise
 	 */
 	short		valid;
 };
 
+#define TSLIB_MT_VALID			(1 << 0)	/* any new data */
+#define TSLIB_MT_VALID_TOOL		(1 << 1)	/* new tool_x or tool_y data */
+
 struct ts_lib_version_data {
 	const char	*package_version;
 	int		version_num;
 	unsigned int	features; /* bitmask, see below */
 };
 
-#define TSLIB_VERSION_MT	(1 << 0)	/* multitouch support */
+#define TSLIB_VERSION_MT		(1 << 0)	/* multitouch support */
+#define TSLIB_VERSION_OPEN_RESTRICTED	(1 << 1)	/* ts_open_restricted() */
 
 enum ts_param {
 	TS_SCREEN_RES = 0,		/* 2 integer args, x and y */
@@ -130,6 +138,16 @@ TSAPI int ts_option(struct tsdev *, enum ts_param, ...);
  */
 extern TSAPI int (*ts_error_fn)(const char *fmt, va_list ap);
 
+/*
+ * Implement this to override open() for the input device and return the fd.
+ */
+extern TSAPI int (*ts_open_restricted)(const char *path, int flags, void *user_data);
+
+/*
+ * Implement this to override close().
+ */
+extern TSAPI void (*ts_close_restricted)(int fd, void *user_data);
+
 /*
  * Returns the file descriptor in use for the touchscreen device.
  */
